;; Generated package description from oauth2.el  -*- no-byte-compile: t -*-
(define-package "oauth2" "0.18.0.20250901.162252" "OAuth 2.0 Authorization Protocol" '((emacs "27.1")) :commit "adf02973c2710ca707471be9db92b9b88b51601b" :authors '(("Julien Danjou" . "julien@danjou.info")) :maintainer '(("Xiyue Deng" . "manphiz@gmail.com") (nil . "emacs-devel@gnu.org")) :keywords '("comm") :url "https://elpa.gnu.org/packages/oauth2.html")
